package de.intevation.flys.importer;

import java.util.List;

import java.io.File;
import java.io.IOException;

import org.apache.log4j.Logger;

import de.intevation.flys.model.River;

import de.intevation.flys.utils.FileTools;

import org.hibernate.Session;
import org.hibernate.Query;

public class ImportRiver
{
    private static Logger log = Logger.getLogger(ImportRiver.class);

    public static final String PEGEL_GLT = "PEGEL.GLT";

    protected String name;

    protected File   wstFile;

    protected File   bbInfoFile;

    protected List<ImportGauge> gauges;

    protected List<ImportAnnotation> annotations;

    protected River peer;

    public ImportRiver() {
    }

    public ImportRiver(String name, File wstFile, File bbInfoFile) {
        this.name       = name;
        this.wstFile    = wstFile;
        this.bbInfoFile = bbInfoFile;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public File getWstFile() {
        return wstFile;
    }

    public void setWstFile(File wstFile) {
        this.wstFile = wstFile;
    }

    public File getBBInfo() {
        return bbInfoFile;
    }

    public void setBBInfo(File bbInfoFile) {
        this.bbInfoFile = bbInfoFile;
    }

    public void parseDependencies() throws IOException {
        parseGauges();
        parseAnnotations();
    }

    public void parseGauges() throws IOException {
        File gltFile = new File(wstFile.getParentFile(), PEGEL_GLT);
        gltFile = FileTools.repair(gltFile);

        if (!gltFile.isFile() || !gltFile.canRead()) {
            log.warn("cannot read gauges from '" + gltFile + "'");
            return;
        }

        PegelGltParser pgltp = new PegelGltParser();
        pgltp.parse(gltFile);

        gauges = pgltp.getGauges();

        for (ImportGauge gauge: gauges) {
            gauge.parseDependencies();
        }
    }

    public void parseAnnotations() throws IOException {
        File riverDir = wstFile.getParentFile().getParentFile();
        AnnotationsParser aparser = new AnnotationsParser();
        aparser.parse(riverDir);

        annotations = aparser.getAnnotations();
    }

    public void storeAnnotations() {
        River river = getPeer();
        for (ImportAnnotation annotation: annotations) {
            annotation.getPeer(river);
        }
    }

    public River getPeer() {
        if (peer == null) {
            Session session = Importer.sessionHolder.get();
            Query query = session.createQuery("from River where name=:name");
            query.setString("name", name);
            List<River> rivers = query.list();
            if (rivers.isEmpty()) {
                peer = new River(name);
                session.save(peer);
            }
            else {
                peer = rivers.get(0);
            }
        }
        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
